searchData={"items":[{"type":"module","title":"PolyPost","doc":"","ref":"PolyPost.html"},{"type":"function","title":"PolyPost.build_and_store!/1","doc":"Builds a list of content for a specific markdown + metadata resource\nand store it in a `Depot` process.","ref":"PolyPost.html#build_and_store!/1"},{"type":"function","title":"PolyPost.build_and_store_all!/0","doc":"Builds all the content for each  markdown + metadata resource\nand store it in a corresponding `Depot` process.","ref":"PolyPost.html#build_and_store_all!/0"},{"type":"module","title":"PolyPost.Builder","doc":"A module used for building content from Markdown files (resources).","ref":"PolyPost.Builder.html"},{"type":"function","title":"PolyPost.Builder.build!/1","doc":"Builds a list of content for a specific marddown + metadata resource.","ref":"PolyPost.Builder.html#build!/1"},{"type":"function","title":"PolyPost.Builder.build_all!/0","doc":"Builds all the content for each resource.","ref":"PolyPost.Builder.html#build_all!/0"},{"type":"module","title":"PolyPost.Depot","doc":"A process to manage the content for a resource (articles, etc.).","ref":"PolyPost.Depot.html"},{"type":"function","title":"PolyPost.Depot.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"PolyPost.Depot.html#child_spec/1"},{"type":"function","title":"PolyPost.Depot.clear/1","doc":"Removes all the content related to the resouce.","ref":"PolyPost.Depot.html#clear/1"},{"type":"function","title":"PolyPost.Depot.find/2","doc":"Finds specific content by a key for the resource.","ref":"PolyPost.Depot.html#find/2"},{"type":"function","title":"PolyPost.Depot.get_all/1","doc":"Gets all content for a resource.","ref":"PolyPost.Depot.html#get_all/1"},{"type":"function","title":"PolyPost.Depot.handle_continue/2","doc":"","ref":"PolyPost.Depot.html#handle_continue/2"},{"type":"function","title":"PolyPost.Depot.init/1","doc":"","ref":"PolyPost.Depot.html#init/1"},{"type":"function","title":"PolyPost.Depot.insert/3","doc":"Inserts content for a resource via a key","ref":"PolyPost.Depot.html#insert/3"},{"type":"function","title":"PolyPost.Depot.start_link/1","doc":"Starts the Depot process with a given name to represent the\nresource.","ref":"PolyPost.Depot.html#start_link/1"},{"type":"module","title":"PolyPost.Depots","doc":"","ref":"PolyPost.Depots.html"},{"type":"function","title":"PolyPost.Depots.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"PolyPost.Depots.html#child_spec/1"},{"type":"function","title":"PolyPost.Depots.start_link/0","doc":"","ref":"PolyPost.Depots.html#start_link/0"},{"type":"behaviour","title":"PolyPost.Resource","doc":"A behavior used to transform a resource (like a markdown file) into structured content.","ref":"PolyPost.Resource.html"},{"type":"callback","title":"PolyPost.Resource.build/3","doc":"Defines a way to return the desired content from the resource.\n\nThis MAY return other keys but MUST have have a key named `key`.","ref":"PolyPost.Resource.html#c:build/3"},{"type":"type","title":"PolyPost.Resource.content/0","doc":"","ref":"PolyPost.Resource.html#t:content/0"},{"type":"type","title":"PolyPost.Resource.key/0","doc":"","ref":"PolyPost.Resource.html#t:key/0"},{"type":"type","title":"PolyPost.Resource.name/0","doc":"","ref":"PolyPost.Resource.html#t:name/0"},{"type":"exception","title":"PolyPost.MissingMetadataError","doc":"","ref":"PolyPost.MissingMetadataError.html"},{"type":"extras","title":"PolyPost","doc":"# PolyPost\n\nA publishing engine with markdown and code highlighting support.","ref":"readme.html"},{"type":"extras","title":"Features - PolyPost","doc":"* Loads files directly from configured paths\n* Stores content in single process-owned ETS tables\n* Supports markdown with structured metadata in JSON\n* Supports multiple directories with markdown files that can be specified as different resources\n* Supports code highlighting in `code` blocks using [makeup](https://github.com/elixir-makeup/makeup)\n* Update content during runtime by calling:\n  * `PolyPost.build_and_store!/1`\n  * `PolyPost.build_and_store_all!/0`","ref":"readme.html#features"},{"type":"extras","title":"Installation - PolyPost","doc":"You can add `poly_post` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [{:poly_post, \"~> 0.1\"}]\nend\n```\n\nIn any of the `config/{config,dev,prod,test}.exs` files\nyou can configure each resources for your content:\n\n```elixir\nconfig :poly_post, :resources,\n  content: [\n    articles: {Article, {:path, \"/path/to/my/markdown/*.md\")}}\n  ]\n```","ref":"readme.html#installation"},{"type":"extras","title":"Basic Usage - PolyPost","doc":"","ref":"readme.html#basic-usage"},{"type":"extras","title":"Loading and Storing Content - PolyPost","doc":"With a file called `my_article1.md` in the configured directory:\n\n```markdown\n{\n  \"title\": \"My Article #1\",\n  \"author\": \"Me\"\n}\n---","ref":"readme.html#loading-and-storing-content"},{"type":"extras","title":"My Article 1 - PolyPost","doc":"This is my first article\n```\n\nYou can create an `Article` module to load your content by\nimplementing the `PolyPost.Resource.build/3` callback:\n\n```elixir\ndefmodule Article do\n  @behaviour PolyPost.Resource\n\n  @enforce_keys [:key, :title, :author, :body]\n  defstruct [:key, :title, :author, :body]\n\n  # Callbacks\n\n  @impl PolyPost.Resource\n  def build(reference, metadata, body) do\n    %__MODULE__{\n      key: reference,\n      title: get_in(metadata, [\"title\"]),\n      author: get_in(metadata, [\"author\"]),\n      body: body\n    }\n  end\nend\n```\n\nThe only requirement is that the struct or map **MUST** contain a key\ncalled `key` that uniquely identifies this content. It **MUST** be a\n`String`.\n\nWhen I call `PolyPost.build_and_store_all!/0`, it will:\n\n1. Load and parse all the markdown files and their metadata\n2. Replace all `code` blocks with highlighted versions if a highlighter is .\n2. Call `Article.build/3` with the `reference` (filename), `metadata` and `content`\n3. Then it stores it in a corresponding `PolyPost.Depot` process.","ref":"readme.html#my-article-1"},{"type":"extras","title":"Using Makeup to Style Code Blocks - PolyPost","doc":"If you wish to use [makeup](https://github.com/elixir-makeup/makeup) to style your `code` blocks, you must\nspecify the needed dependencies in your `mix.exs` file.\n\nFor example, if you wanted to highlight Elixir, Erlang and HTML in your\nproject, then I would specify the following:\n\n```elixir\ndefp deps do\n  [\n    {:makeup, \"~> 1.1\"},\n    {:makeup_elixir, \">= 0.0.0\"},\n    {:makeup_erlang, \">= 0.0.0\"},\n    {:makeup_html, \">= 0.0.0\"}\n  ]\nend\n```\n\nThen you can use tags in your markdown code blocks like so and it will\nautomatically highlight them:\n\n````markdown\n```elixir\ndef start_link(arg) do\n  GenServer.start_link(__MODULE__, arg, name: __MODULE__)\nend\n```\n````","ref":"readme.html#using-makeup-to-style-code-blocks"},{"type":"extras","title":"Retrieving Content - PolyPost","doc":"You can retrieve content using the functions on the `PolyPost.Depot`\nmodule to access the associated ETS table that stores your data:\n\n1. `find/2` - find a specific content by `key` for the resource\n2. `get_all/1` - gets all content for a resource\n\nFor example:\n\n```elixir\nPolyPost.Depot.find(:articles, \"my_article1.md\")\n=> %Article{...}\n```\n\nand\n\n```elixir\nPolyPost.Depot.get_all(:articles)\n=> [%Article{...}]\n```","ref":"readme.html#retrieving-content"},{"type":"extras","title":"Differences from NimblePublisher - PolyPost","doc":"This library was heavily inspired by [NimblePublisher](https://github.com/dashbitco/nimble_publisher), but\nit **IS** different.\n\n* Metadata in markdown files are specified in JSON instead of Elixir\n* Designed to be updated at runtime via calling refresh methods (`PolyPost.build_and_store!/1` or `PolyPost.build_and_store_all!/0`)\n* Must be configured through `Application` config using `:poly_post`\n* Stores content in ETS instead of compiling directly into modules","ref":"readme.html#differences-from-nimblepublisher"},{"type":"extras","title":"License - PolyPost","doc":"This software is licensed under the [Apache-2.0 License](LICENSE).","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll changes worthy of mention are noted here.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [0.1.0] - 2024-08-17","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Added inline docs + typespec public functions\n- Added tests for `PolyPost.Builder` and `PolyPost.Depot` modules\n- Added support for code highlighting using `makeup` in `code` blocks\n- Added storage of content into ETS tables accessible via the `PolyPost.Depot` processes\n- Added support to load files directly from configured, splattable paths\n- Added `PolyPost.Resource` behaviour to specify `build/3` function callbacks for managing parsed markdown + metadata\n- Added `README` with documentation for basic installing and usage of this library\n- Added license (Apache 2.0) to project","ref":"changelog.html#added"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright [yyyy] [name of copyright owner]\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}